import { HttpMethod, FunctionUrlCorsOptions } from "aws-cdk-lib/aws-lambda";
import { Duration } from "./duration.js";
export interface CorsProps {
    /**
     * Specifies whether credentials are included in the CORS request.
     */
    allowCredentials?: boolean;
    /**
     * The collection of allowed headers.
     */
    allowHeaders?: string[];
    /**
     * The collection of allowed HTTP methods.
     *
     * @example
     * ```js
     * // Allow all methods
     * allowMethods: ["*"]
     *
     * // Allow specific methods
     * allowMethods: ["GET", "POST"]
     * ```
     */
    allowMethods?: (keyof Omit<typeof HttpMethod, "ALL"> | "*")[];
    /**
     * The collection of allowed origins.
     *
     * @example
     * ```js
     * // Allow all origins
     * allowOrigins: ["*"]
     *
     * // Allow specific origins. Note that the url protocol, ie. "https://", is required.
     * allowOrigins: ["https://domain.com"]
     * ```
     */
    allowOrigins?: string[];
    /**
     * The collection of exposed headers.
     */
    exposeHeaders?: string[];
    /**
     * Specify how long the results of a preflight response can be cached
     */
    maxAge?: Duration;
}
export declare function buildCorsConfig(cors?: boolean | CorsProps): FunctionUrlCorsOptions | undefined;
